==> haskell-safecopy-0.9.3.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safecopy
version: 0.9.3.1
id: safecopy-0.9.3.1-3kmdSnd9TxSGD9A8MvyrZm
key: safecopy-0.9.3.1-3kmdSnd9TxSGD9A8MvyrZm
license: PublicDomain
maintainer: Lemmih <lemmih@gmail.com>
homepage: https://github.com/acid-state/safecopy
synopsis: Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.
category: Data, Parsing
author: David Himmelstrup, Felipe Lessa
exposed: True
exposed-modules:
    Data.SafeCopy Data.SafeCopy.Internal
hidden-modules: Data.SafeCopy.Instances Data.SafeCopy.SafeCopy
                Data.SafeCopy.Derive
abi: 06b8d785c3a6f3645e4c71323f67f206
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/safecopy-0.9.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/safecopy-0.9.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/safecopy-0.9.3.1
hs-libraries: HSsafecopy-0.9.3.1-3kmdSnd9TxSGD9A8MvyrZm
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi containers-0.5.7.1
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html: /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safecopy-0.9.3.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safecopy
version: 0.9.3.2
id: safecopy-0.9.3.2-EiqtFdUFw7p6NJo2WzLmyS
key: safecopy-0.9.3.2-EiqtFdUFw7p6NJo2WzLmyS
license: PublicDomain
maintainer: Lemmih <lemmih@gmail.com>
homepage: https://github.com/acid-state/safecopy
synopsis: Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.
category: Data, Parsing
author: David Himmelstrup, Felipe Lessa
exposed: True
exposed-modules:
    Data.SafeCopy Data.SafeCopy.Internal
hidden-modules: Data.SafeCopy.Instances Data.SafeCopy.SafeCopy
                Data.SafeCopy.Derive
abi: c9daa634e6d838038932d278d77768c9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/safecopy-0.9.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/safecopy-0.9.3.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/safecopy-0.9.3.2
hs-libraries: HSsafecopy-0.9.3.2-EiqtFdUFw7p6NJo2WzLmyS
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1
    cereal-0.5.4.0-1RWVeyNi1If1ir8gxayRPi containers-0.5.7.1
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp template-haskell-2.11.0.0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html: /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
